@@ -21,8 +21,8 @@
 """
 
 import astroid
+from astroid import nodes
 
-from pylint.constants import BUILTINS
 from pylint.pyreverse.diagrams import ClassDiagram, PackageDiagram
 from pylint.pyreverse.utils import LocalsVisitor
 
@@ -78,7 +78,7 @@ class DiaDefGenerator:
         """true if builtins and not show_builtins"""
         if self.config.show_builtin:
             return True
-        return node.root().name != BUILTINS
+        return node.root().name != "builtins"
 
     def add_class(self, node):
         """visit one class and add it to diagram"""
@@ -104,7 +104,7 @@ class DiaDefGenerator:
             for node in association_nodes:
                 if isinstance(node, astroid.Instance):
                     node = node._proxied
-                if not (isinstance(node, astroid.ClassDef) and self.show_node(node)):
+                if not (isinstance(node, nodes.ClassDef) and self.show_node(node)):
                     continue
                 yield node
 
